
# #############################################################
# ### Generated by GenerateVarMap.PL.
# ###
# ### Please edit the master and *not* this file.
# ### Date of render: Fri Mar  7 13:15:44 2008
##############################################################

package sys::os;

use strict;
use warnings;
use version;
our $VERSION = qv('0.2');

use Carp 'confess';
use Scalar::Util 'blessed';


BEGIN {
    my $EAGER_PRECALCULATED = {
        'name' => $^O,
    };

    sub __get_eager_var_value {
        my ($self, $var_name) = @_;
        confess "No eager variable with name ($var_name)"
            if not exists $EAGER_PRECALCULATED->{$var_name};
        return $EAGER_PRECALCULATED->{$var_name};
    }
}
use Class::Dot2;
{



    sub child_error {
                    if ($_[1]) {
                return $? = $_[1];
            };
        
                return $?; # SCALAR        
    }
    sub errno {
                    if ($_[1]) {
                return $! = $_[1];
            };
        
                return $!; # SCALAR        
    }
    sub extended_error {
                    if ($_[1]) {
                return $^E = $_[1];
            };
        
                return $^E; # SCALAR        
    }
    sub error {
                    if ($_[1]) {
                return $! = $_[1];
            };
        
                return $!; # SCALAR        
    }
    sub name {
                    if ($_[1]) {
                return $^O = $_[1];
            };
        
                return ($_[0]||__PACKAGE__)->__get_eager_var_value("name");
        
    }
    sub fd_max {
                    if ($_[1]) {
                return $^F = $_[1];
            };
        
                return $^F; # SCALAR        
    }

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab tabstop=4 shiftwidth=4 shiftround

__END__

=begin wikidoc

= NAME

sys::os - Information about the currently running Perl interpreter.

= VERSION

This document describes sys::os version %%VERSION%%

= SYNOPSIS

    use sys::os;


    my $child_error = sys::os->child_error;

    sys::os->child_error($new_value);
    
    my $errno = sys::os->errno;

    sys::os->errno($new_value);
    
    my $extended_error = sys::os->extended_error;

    sys::os->extended_error($new_value);
    
    my $error = sys::os->error;

    sys::os->error($new_value);
    
    my $name = sys::os->name;

    sys::os->name($new_value);
    
    my $fd_max = sys::os->fd_max;

    sys::os->fd_max($new_value);
    

= DESCRIPTION

This is the object oriented version of [English].

This module provides access to some objects used or maintained by
the interpreter and to functions that interact strongly with the interpreter.


= SUBROUTINES/METHODS

== CLASS/INSTANCE METHODS


=== {child_error($optional_new_value)}

Returns child_error as a SCALAR.


=== {errno($optional_new_value)}

Returns errno as a SCALAR.


=== {extended_error($optional_new_value)}

Returns extended_error as a SCALAR.


=== {error($optional_new_value)}

Returns error as a SCALAR.


=== {name($optional_new_value)}

Returns name as a SCALAR.


=== {fd_max($optional_new_value)}

Returns fd_max as a SCALAR.


= DEPENDENCIES

* [version]

* [Class::Dot]

* [Scalar::Util]

= INCOMPATIBILITIES

None known.

= BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests to
[bug-class-dot@rt.cpan.org|mailto:bug-class-dot@rt.cpan.org], or through the
web interface at [CPAN Bug tracker|http://rt.cpan.org].

= SEE ALSO

* [perlvar]

* [English]

= AUTHOR

Ask Solem, [asksh@cpan.org].

= LICENSE AND COPYRIGHT

Copyright (c), 2007 Ask Solem [ask@0x61736b.net|mailto:ask@0x61736b.net].

{sys} is distributed under the Modified BSD License.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

3. The name of the author may not be used to endorse or promote products
derived
from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED                        
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF                                
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO                          
EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,                              
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,                        
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR                      
BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER                       
IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)                          
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE                          
POSSIBILITY OF SUCH DAMAGE.

= DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE
SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE
STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE
SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND
PERFORMANCE OF THE SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE,
YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY
COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE
SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE LIABLE TO YOU FOR DAMAGES,
INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING
OUT OF THE USE OR INABILITY TO USE THE SOFTWARE (INCLUDING BUT NOT LIMITED TO
LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR
THIRD PARTIES OR A FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER
SOFTWARE), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
POSSIBILITY OF SUCH DAMAGES.

=end wikidoc

=for stopwords expandtab shiftround
